summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorChristian Wieninger <cwieninger (at) gmx (dot) de>2008-07-06 10:05:20 +0200
committerChristian Wieninger <cwieninger (at) gmx (dot) de>2008-07-06 10:05:20 +0200
commit4ab563aad38a3278062f21bbd76375f4c92e2839 (patch)
tree8afc36d5e1c977b5fc6c0289e63487f504552e34
parent66dd9fb9e25bdad629416584e2f4a1251bd980d0 (diff)
downloadvdr-plugin-epgsearch-4ab563aad38a3278062f21bbd76375f4c92e2839.tar.gz
vdr-plugin-epgsearch-4ab563aad38a3278062f21bbd76375f4c92e2839.tar.bz2
ignore running events when searching for repeats for searchtimers with 'avoid repeats'
-rw-r--r--epgsearchext.c4
-rw-r--r--epgsearchext.h1
-rw-r--r--po/it_IT.po41
-rw-r--r--recstatus.c3
4 files changed, 27 insertions, 22 deletions
diff --git a/epgsearchext.c b/epgsearchext.c
index f6b3452..7efd744 100644
--- a/epgsearchext.c
+++ b/epgsearchext.c
@@ -872,6 +872,9 @@ cEvent * cSearchExt::GetEventBySearchExt(const cSchedule *schedules, const cEven
free(szTest);
szTest = NULL;
}
+
+ if (skipRunningEvents && tNow > p->StartTime())
+ continue;
// ignore events without title
if (!p->Title() || !*p->Title())
@@ -1071,6 +1074,7 @@ cSearchResults* cSearchExt::Run(int PayTVMode, bool inspectTimerMargin, int eval
CheckRepeatTimers(pSearchResults);
}
+ skipRunningEvents = false;
return pSearchResults;
}
diff --git a/epgsearchext.h b/epgsearchext.h
index baa2234..6d0929e 100644
--- a/epgsearchext.h
+++ b/epgsearchext.h
@@ -163,6 +163,7 @@ public:
int ignoreMissingEPGCats;
int unmuteSoundOnSwitch;
+ bool skipRunningEvents;
static char *buffer;
public:
cSearchExt(void);
diff --git a/po/it_IT.po b/po/it_IT.po
index a7d0517..cd7c4ee 100644
--- a/po/it_IT.po
+++ b/po/it_IT.po
@@ -9,7 +9,7 @@ msgid ""
msgstr ""
"Project-Id-Version: VDR 1.5.7\n"
"Report-Msgid-Bugs-To: <cwieninger@gmx.de>\n"
-"POT-Creation-Date: 2007-11-16 16:11+0100\n"
+"POT-Creation-Date: 2008-07-03 20:44+0200\n"
"PO-Revision-Date: 2008-06-29 03:25+0100\n"
"Last-Translator: Diego Pierotto <vdr-italian@tiscali.it>\n"
"Language-Team: <vdr@linuxtv.org>\n"
@@ -50,10 +50,6 @@ msgstr "Il nome gruppo è vuoto!"
msgid "Group name already exists!"
msgstr "Nome gruppo già esistente!"
-#, c-format
-msgid "%d timer conflict(s)! First at %s. Show them?"
-msgstr "%d conflitto timer! Primo alle %s. Mostrarli?"
-
msgid "Direct access to epgsearch's conflict check menu"
msgstr "Accesso diretto al menu di verifica conflitti di epgsearch"
@@ -66,6 +62,10 @@ msgstr "Informazioni conflitto nel menu principale"
msgid "next"
msgstr "prossimo"
+#, c-format
+msgid "%d timer conflict(s)! First at %s. Show them?"
+msgstr "%d conflitto timer! Primo alle %s. Mostrarli?"
+
msgid "search the EPG for repeats and more"
msgstr "Cerca nella guida EPG: per parole, repliche e altro"
@@ -864,21 +864,6 @@ msgstr "Informazioni ausiliari"
msgid "Button$Aux info"
msgstr "Info ausiliari"
-msgid "Button$Actions"
-msgstr "Azioni"
-
-msgid "Search entries"
-msgstr "Valori ricerca"
-
-msgid "active"
-msgstr "attivo"
-
-msgid "Edit$Delete search?"
-msgstr "Eliminare criteri?"
-
-msgid "Delete all timers created from this search?"
-msgstr "Eliminare tutti i timer creati da questa ricerca?"
-
msgid "Search actions"
msgstr "Azioni ricerca"
@@ -936,6 +921,21 @@ msgstr "Copia"
msgid "Copy this entry to templates?"
msgstr "Copiare questo valore nei modelli?"
+msgid "Delete all timers created from this search?"
+msgstr "Eliminare tutti i timer creati da questa ricerca?"
+
+msgid "Button$Actions"
+msgstr "Azioni"
+
+msgid "Search entries"
+msgstr "Valori ricerca"
+
+msgid "active"
+msgstr "attivo"
+
+msgid "Edit$Delete search?"
+msgstr "Eliminare criteri?"
+
msgid "Edit search"
msgstr "Modifica ricerca"
@@ -1198,4 +1198,3 @@ msgstr "in %02ldh"
#, c-format
msgid "in %02ldm"
msgstr "in %02ldm"
-
diff --git a/recstatus.c b/recstatus.c
index 4603d72..dfa99b3 100644
--- a/recstatus.c
+++ b/recstatus.c
@@ -148,7 +148,8 @@ void cRecStatusMonitor::Recording(const cDevice *Device, const char *Name, const
// check for search timers to delete automatically
SearchExts.CheckForAutoDelete(search);
- // trigger a search timer update
+ // trigger a search timer update (skip running events)
+ search->skipRunningEvents = true;
updateForced = 1;
}
else if (tiR->lastBreak == 0) // store first break